# -*- coding: utf-8 -*-

from SLiCAP import *
prj = initProject('Active antenna specifications')

htmlPage('Active Antenna Specifications')
head2html('Functional specifications')
text2html('The following functions need to be performed by the active antenna:')

head3html('Conversion of E-field into an electrical voltage or current')
text2html('This function is performed by the short rod antenna.')

head3html('Conversion of the electrical output signal of the antenna into a voltage or current across a 50 $\\Omega$ load.')
text2html('This function is performed by the amplifier.')

head3html('Splitting and/or combining the power supply and the output signal of the amplifier on the cable.')
text2html('This function will be performed by passive filters at both ends of the cable.')

head2html('Performance specifications')

head3html('Scope')
text2html('The design of the antenna and the design of the power splitter/combiner are not part of this design exercise.')
text2html('The antenna will have a length of 50cm and a diameter of 5mm. The convergion gain from E-field to open-circuit output voltage equals its length.')
text2html('The source capacitance of this antenna over the frequency range of interest is about 6.3pF.')
text2html('The amplifier will be supplied from a low-noise supply source that is connected to the amplifier with a separate cable.')
text2html('The performance specifications of the coplete signal chain that consists of the antenna, the amplifier and the cable terminated with 50$\\Omega$ are given below.')

head3html('Antenna capacitance')
text2html('The antenna capacitance $C_A$ [F] equals:')
C_A = 6.4e-12
eqn2html('C_A', C_A)

head3html('Antenna conversion gain')
text2html('The antenna conversion gain $G_A$ [m] equals:')
G_A = 0.5
eqn2html('G_A', G_A)

head3html('Active antenna gain')
text2html('The gain of the active antenna $G_{AA}$ in [m] is defined as the gain from the E field at the input of the antenna to the voltage across the 50 $\\Omega$ termination of the cable:')
G_AA = 0.5
eqn2html('G_AA', G_AA)

head3html('Maximum field strength at the antenna:')
text2html('The maximum value of the RMS field strength at the antenna [V/m] equals:')
E_A = 0.45
eqn2html('E_A', E_A)
text2html('The crest factor is not specified. Hence is it not possible to determine the peak-to-peak value of the E-field.')

head3html('Maximum output level')
text2html('A gain compression of 1dB is allowed at a single-frequency output signal level $V_{o1dB}$ [V] of 0dBm (225mV RMS).')
V_o_1dB = 0.225
eqn2html('V_o_1dB', V_o_1dB)

head3html('Frequency range of interest')
f_l = 10e3
f_h = 30e6
text2html('The (-3dB) frequency range of interest ranges from $f_l$ to $f_h$ [Hz], where:')
eqn2html('f_l', f_l)
eqn2html('f_h', f_h)

head3html('Mid band inaccuracy')
text2html('The maximum inaccuracy $\\delta_{GAAmax}$ [-] of the gain at midband frequencies $f_{mbl}$ to $f_{mbf}$ [Hz] should be:')
delta_G_AA_max = 0.2
f_mbl = 1e5
f_mbh = 1e6
eqn2html('delta_G_AA_max', delta_G_AA_max)
eqn2html('f_mbl', f_mbl)
eqn2html('f_mbh', f_mbh)

head3html('Source-referred noise')
text2html('The antenna-referred (E-field) noise in [V^2/m/Hz] over the frequency range of interest should be less then:')
S_E_floor = 95e-18
S_E_lf    = 3E-6/ini.frequency**2
S_E = S_E_floor + S_E_lf
eqn2html('S_E', S_E)

head3html('Active antenna load')
text2html('The load of the active antenna is a 50$\\Omega$ cable terminated with 50$\\Omega$. This cable should be driven from its charactersitic impedance.')
text2html('Hence, the output impedance $Z_o$ [$\\Omega$] of the amplifier must equal its load impedance $Z_l$ [$\\Omega$] :')
Z_o = 50
Z_l = 50
eqn2html('Z_l', Z_l)
eqn2html('Z_o', Z_o)

head2html('Environmental Specifications')
text2html('Temperature range and ESD conditions are mentioned in the application description.')

head3html('Operating temperature range')
text2html('The operating temperature ranges from $T_{man}$ to $T_{max}$ [C], where:')
T_min = -25
T_max = 70
eqn2html('T_min', T_min)
eqn2html('T_max', T_max)

head3html('ESD environmental conditions')
text2html('The ESD conditions have not been specified.')

head2html('Cost factors')

head3html('PCB area')
text2html('The width $PCB_W$ [mm], the length $PCB_L$ [mm] and the heifht $PCB_H$ [mm] of the PCB should maximally be:')
PCB_W = 25
PCB_L = 50
PCB_H = 15
eqn2html('PCB_W', PCB_W)
eqn2html('PCB_L', PCB_L)
eqn2html('PCB_H', PCB_H)

head3html('Supply voltage')
text2html('The maximum supply voltage $V_{supplyMax}$ [V] should be:')
V_supply_Max = 10
eqn2html('V_supply_Max', V_supply_Max)

head3html('Supply power')
text2html('The maximum power taken from the sullpy $P_{supplyMax}$ [W] should be:')
P_supply_Max = 0.25
eqn2html('P_supply_Max', P_supply_Max)